%----------------------------------------------------------------------
%Adapted by Bruce Land from:
% Physiology 317 - Methods in Computational Neurobiology
% HODGKIN-HUXLEY: Response of Squid Axon to Current Injection
% M. Nelson  1995, 1997
%----------------------------------------------------------------------

clear
clf
orient landscape

%%%%%%%%%%%%%%%%%%%%%%%
% INITIALIZATION
%%%%%%%%%%%%%%%%%%%%%%%
DT = 0.025;
TMAX = 100;
t = 0:DT:TMAX;

VREST = -60.0;

GNA = 120.0;	% mS/cm^2
GK = 36.0;	% mS/cm^2
GLEAK = 0.3;	% mS/cm^2

ENA = 115.0 + VREST;	% mV
EK = -12.0 + VREST;	% mV
ELEAK = 10.613 + VREST;	% mV

C_M = 1.0;	% uF/cm^2

%current strength
INJECT_LIST = [6.0 10.0 15 20];

for ival = 1:4
   
   I = INJECT_LIST(ival)*(t>5 & t<=90);
   
   %%%%%%%%%%%%%%%%%%%%%%%
   % MAIN SIMULATION LOOP
   %%%%%%%%%%%%%%%%%%%%%%%
   
   clear v  m  h  n				% clear old varibles
   v = VREST;					% initial membrane voltage
   m = alpha_m(v-VREST)/(alpha_m(v-VREST)+beta_m(v-VREST));	% initial (steady-state) m
   h = alpha_h(v-VREST)/(alpha_h(v-VREST)+beta_h(v-VREST));	% initial (steady-state) h
   n = alpha_n(v-VREST)/(alpha_n(v-VREST)+beta_n(v-VREST));	% initial (steady-state) n
   
   for i=2:length(t)
      
      M = m(i-1);	% get values from last time step
      H = h(i-1);	% (hopefully this substitution makes 
      N = n(i-1);	% the following code a bit easier to read)
      V = v(i-1);
      
      gNa = GNA * M^3 * H;
      gK  = GK  * N^4;
      
      mdot = alpha_m(V-VREST)*(1-M) - beta_m(V-VREST)*M;
      hdot = alpha_h(V-VREST)*(1-H) - beta_h(V-VREST)*H;
      ndot = alpha_n(V-VREST)*(1-N) - beta_n(V-VREST)*N;
      vdot = (I(i-1) - gNa*(V-ENA) - gK*(V-EK) - GLEAK*(V-ELEAK))/C_M;
      
      m(i) = m(i-1) + mdot*DT;		% Euler integration
      h(i) = h(i-1) + hdot*DT;
      n(i) = n(i-1) + ndot*DT;
      v(i) = v(i-1) + vdot*DT;
   end
   
   subplot(2,2,ival);
   plot(t,v,'b-'); hold on;
   plot(t,I,'r:')
   str = sprintf('Inject = %2.2f \\muA/cm^2',INJECT_LIST(ival));
   title(str);
   drawnow;
end

%%%%%%%%%%%%%%%%%%
% label plots
%%%%%%%%%%%%%%%%%%
subplot(221); 
ylabel('v (mV)')
%axis([0 TMAX -2 2])

subplot(223); 
xlabel('t (msec)'); ylabel('v (mV)')
%axis([0 TMAX -2 2])

subplot(222); 
ylabel('v (mV)')
%axis([0 TMAX -50 150])

subplot(224); 
xlabel('t (msec)'); ylabel('v (mV)')
%axis([0 TMAX -50 150])
